fireworks.examples.custom_firetasks package — FireWorks 2.0.4 documentation

# fireworks.examples.custom_firetasks package

## Subpackages

- fireworks.examples.custom_firetasks.hello_world package
  - Submodules
  - fireworks.examples.custom_firetasks.hello_world.hello_world_run module
  - fireworks.examples.custom_firetasks.hello_world.hello_world_task module
    - `HelloTask`
      - `HelloTask.run_task()`
  - Module contents
- fireworks.examples.custom_firetasks.merge_task package
  - Submodules
  - fireworks.examples.custom_firetasks.merge_task.merge_task module
    - `TaskA`
      - `TaskA.run_task()`
    - `TaskB`
      - `TaskB.run_task()`
    - `TaskC`
      - `TaskC.run_task()`
  - Module contents

## Module contents